# sankalp

A simple interactive CLI for Sankalp Shrivastava.

## run 'sankalp' after installing to learn more about me!

## Install Sankalp CLI using pip:

```python
pip install sankalp
```

## After installation, run this to learn more about me!

```python
sankalp
```